@@ -1,19 +1,9 @@
 /*
  Copyright (C) 2006-2007 M.A.L. Marques
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU Lesser General Public License as published by
- the Free Software Foundation; either version 3 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ This Source Code Form is subject to the terms of the Mozilla Public
+ License, v. 2.0. If a copy of the MPL was not distributed with this
+ file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
 
 #ifndef _XC_H
@@ -147,9 +137,20 @@ struct xc_func_type{
   struct xc_func_type **func_aux;      /* most GGAs are based on a LDA or other GGAs  */
   double *mix_coef;                      /* coefficients for the mixing */
 
-  double cam_omega;                      /* range-separation parameter for range-separated hybrids */
-  double cam_alpha;                      /* fraction of Hartree-Fock exchange for normal or range-separated hybrids */
-  double cam_beta;                       /* fraction of short-range exchange for range-separated hybrids */
+  /**
+     Parameters for range-separated hybrids
+     cam_omega: the range separation constant
+     cam_alpha: fraction of full Hartree-Fock exchange, used both for
+                usual hybrids as well as range-separated ones
+     cam_beta:  fraction of short-range only(!) exchange in
+                range-separated hybrids
+
+     N.B. Different conventions for alpha and beta can be found in
+     literature. In the convention used in libxc, at short range the
+     fraction of exact exchange is cam_alpha+cam_beta, while at long
+     range it is cam_alpha.
+  */
+  double cam_omega, cam_alpha, cam_beta;
 
   double nlc_b;                          /* Non-local correlation, b parameter */
   double nlc_C;                          /* Non-local correlation, C parameter */
